@@ -1,3 +1,6 @@
+"""init module, providing information about the arfs package
+"""
+
 import os.path
 
 # The directory containing this file
@@ -5,7 +8,7 @@ HERE = os.path.abspath(os.path.dirname(__file__))
 
 # get key package details from taco/__version__.py
 ABOUT = {}  # type: ignore
-with open(os.path.join(HERE, '__version__.py')) as f:
+with open(os.path.join(HERE, "__version__.py"), encoding="utf-8") as f:
     exec(f.read(), ABOUT)
 
-__version__ = ABOUT['__version__']
\ No newline at end of file
+__version__ = ABOUT["__version__"]
